@@ -6,6 +6,7 @@ import pathlib
 import tempfile
 from pathlib import Path
 
+import pytest
 from transformers import CONFIG_MAPPING
 from transformers import AutoModelWithLMHead
 from transformers import DataCollatorForLanguageModeling
@@ -13,8 +14,9 @@ from transformers import Trainer
 from transformers import TrainingArguments
 
 from gcgc import KmerTokenizer
-from gcgc import third_party
 from gcgc.tests.fixtures import PF01152_PATH_FULL
+from gcgc.third_party import hf
+from gcgc.third_party import hf_datasets
 
 
 def test_transformers_model(tmpdir):
@@ -22,11 +24,9 @@ def test_transformers_model(tmpdir):
     tmpdir = Path(tmpdir)
 
     kmer_tokenizer = KmerTokenizer(alphabet="extended_protein")
-    transformers_tokenizer = third_party.GCGCTransformersTokenizer.from_kmer_tokenizer(
-        kmer_tokenizer
-    )
+    transformers_tokenizer = hf.GCGCTransformersTokenizer.from_kmer_tokenizer(kmer_tokenizer)
 
-    dataset = third_party.GenomicDataset.from_path(PF01152_PATH_FULL, transformers_tokenizer)
+    dataset = hf.GenomicDataset.from_path(PF01152_PATH_FULL, transformers_tokenizer)
     data_collator = DataCollatorForLanguageModeling(tokenizer=transformers_tokenizer, mlm=True)
 
     config = CONFIG_MAPPING["bert"](
@@ -56,9 +56,7 @@ def test_tokenizer():
     """Test the tokenizer interface."""
     kmer_tokenizer = KmerTokenizer(alphabet="extended_protein", conform_length=9)
 
-    transformers_tokenizer = third_party.GCGCTransformersTokenizer.from_kmer_tokenizer(
-        kmer_tokenizer
-    )
+    transformers_tokenizer = hf.GCGCTransformersTokenizer.from_kmer_tokenizer(kmer_tokenizer)
 
     with tempfile.TemporaryDirectory() as tempdir:
         temppath = pathlib.Path(tempdir)
@@ -66,9 +64,7 @@ def test_tokenizer():
         model_path.mkdir(exist_ok=True)
 
         transformers_tokenizer.save_pretrained(str(model_path))
-        transformers_tokenizer = third_party.GCGCTransformersTokenizer.from_pretrained(
-            str(model_path)
-        )
+        transformers_tokenizer = hf.GCGCTransformersTokenizer.from_pretrained(str(model_path))
 
     # Includes start and stop ids.
     expected = [1, 15, 22, 15, 2]
@@ -87,3 +83,12 @@ def test_tokenizer():
 
     # Test decode
     assert transformers_tokenizer.decode([1, 15, 22, 3, 2, 0]) == ">MV#<|"
+
+
+@pytest.mark.skip
+def test_download_swissprot():
+    """Test it's possible to download the swissprot dataset."""
+    ref = hf_datasets.UniprotDataset(name="sprot")
+    ref.download_and_prepare()
+    dataset = ref.as_dataset()
+    assert "sprot" in dataset.keys()
